@@ -7,6 +7,10 @@
 #' @param y a numeric \code{vector} that should be correlated with \code{x}.
 #' @param method the method to compute the linear correlation between \code{x} and \code{y}.
 #' @param test.na a boolean value indicating whether input data should be checked for \code{NA} values.
+#' @param epsilon a small value to address cases where division by zero occurs. Default is `0.00001`.
+#' This is only used for `method = "pearson"`.
+#' @param num.threads an integer specifying the number of threads to be used for parallel computations.
+#' Default is `NULL`, which uses the value from the `RCPP_PARALLEL_NUM_THREADS` environment variable or `2` if not set.
 #' @author Hajk-Georg Drost
 #' @details
 #'  
@@ -24,7 +28,7 @@
 #'  \item \emph{Pearson's correlation coefficient (centred)} : 
 #'  } 
 #' @export 
-lin.cor <- function(x,y = NULL, method = "pearson", test.na = FALSE){
+lin.cor <- function(x, y = NULL, method = "pearson", test.na = FALSE, epsilon = 0.00001, num.threads = NULL){
         
         if(is.null(y)){
                 if(!is.element(class(x), c("matrix","data.frame")))
@@ -41,28 +45,28 @@ lin.cor <- function(x,y = NULL, method = "pearson", test.na = FALSE){
         if(method == "pearson"){
                 
                 if(inherits(x, "matrix")){
-                        cor.coef <-  DistMatrixWithoutUnitMAT(x,pearson_corr_centred,test.na)
+                        cor.coef <- distance_cpp(x, "pearson", p = NULL, test_na = test.na, unit = "log", epsilon = epsilon, num_threads = num.threads)
                 }
                 else if ((is.vector(x)) && (is.vector(y))){
-                        cor.coef <- pearson_corr_centred(x,y,test.na)
+                        cor.coef <- dist_one_one(x, y, method = "pearson", testNA = test.na)
                 }
         }
         
         if(method == "pearson2"){
                 
                 if(inherits(x, "matrix")){
-                        cor.coef <-  DistMatrixWithoutUnitMAT(x,pearson_corr_uncentred,test.na)
+                        stop("The 'pearson2' method is not supported for matrix input in the new parallel backend.")
                 } else if ((is.vector(x)) && (is.vector(y))){
-                        cor.coef <-  pearson_corr_uncentred(x,y,test.na)
+                        cor.coef <- pearson_corr_uncentred(x, y, test.na)
                 }
         }
         
         if(method == "sq_pearson"){
                 
                 if(inherits(x, "matrix")){
-                        cor.coef <-  DistMatrixWithoutUnitMAT(x,squared_pearson_corr,test.na)
+                        cor.coef <- distance_cpp(x, "squared_pearson", p = NULL, test_na = test.na, unit = "log", epsilon = epsilon, num_threads = num.threads)
                 } else if ((is.vector(x)) && (is.vector(y))){
-                        cor.coef <-  squared_pearson_corr(x,y,test.na)
+                        cor.coef <- dist_one_one(x, y, method = "squared_pearson", testNA = test.na)
                 }
         }
         
@@ -75,8 +79,3 @@ lin.cor <- function(x,y = NULL, method = "pearson", test.na = FALSE){
         
         return (cor.coef)
 }
-
-
-
-
-
